# =================================================================
# Licensed Materials - Property of IBM
#
# (c) Copyright IBM Corp. 2013, 2015 All Rights Reserved
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
# =================================================================

import binascii

from oslo_config.ibm import secret_opt_base_handler
from oslo_utils import encodeutils
import codecs
from oslo_serialization import base64


class SecretOptHandler(secret_opt_base_handler.SecretOptHandlerBase):

    ENCODED_PREFIX = '[IBM:v1]'

    def _is_encoded(self, value):
        """Accept a value and return None if the value is not encoded.

        :param value:The text to be verified
        :returns: None if the value is not encoded,
        else return the value decoded by 'base64'.
        """
        try:
            return base64.decode_as_bytes(value).startswith(b'[IBM:v1]')
        except binascii.Error:
            return False
        except AttributeError:
            return False
        except TypeError:
            return False

    def decode(self, opt_value):
        """Decode the opt value.

        If the opt is not encoded, return the given value.
        :param opt_value:The text to be decoded.
        :returns: The decoded value
        """

        decoded_base64 = self._is_encoded(opt_value)
        if decoded_base64:
            decoded = base64.decode_as_text(opt_value)
            opt_value = codecs.decode(decoded[8:], 'rot13')

        return opt_value

